# Customize

If you would like to customize the files in this directory, copy all the files
you need (minus this README) to a different location and set `webroot` in
`/etc/zeitgitter.conf` to your new location.

:warning: Files in this Python package directory will be overwritten by
updates, so any modifications *here* will be lost.
